@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: msgwin.c 13205 2012-02-04 23:59:42Z jordan $
+ * $Id: msgwin.c 13388 2012-07-14 19:26:55Z jordan $
  */
 
 #include <errno.h>
@@ -456,7 +456,7 @@ gtr_message_log_window_new( GtkWindow * parent, TrCore * core )
     gtk_window_set_title( GTK_WINDOW( win ), _( "Message Log" ) );
     gtk_window_set_default_size( GTK_WINDOW( win ), 560, 350 );
     gtk_window_set_role( GTK_WINDOW( win ), "message-log" );
-    vbox = gtr_vbox_new( FALSE, 0 );
+    vbox = gtk_box_new( GTK_ORIENTATION_VERTICAL, 0 );
 
     /**
     ***  toolbar
@@ -464,10 +464,8 @@ gtr_message_log_window_new( GtkWindow * parent, TrCore * core )
 
     toolbar = gtk_toolbar_new( );
     gtk_toolbar_set_style( GTK_TOOLBAR( toolbar ), GTK_TOOLBAR_BOTH_HORIZ );
-#if GTK_CHECK_VERSION( 3,0,0 )
     gtk_style_context_add_class( gtk_widget_get_style_context( toolbar ),
                                  GTK_STYLE_CLASS_PRIMARY_TOOLBAR );
-#endif
 
     item = gtk_tool_button_new_from_stock( GTK_STOCK_SAVE_AS );
     g_object_set( G_OBJECT( item ), "is-important", TRUE, NULL );
