@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: tr-window.h 10937 2010-07-04 06:07:21Z charles $
+ * $Id: tr-window.h 13391 2012-07-14 22:44:41Z jordan $
  *
- * Copyright (c) 2006-2008 Transmission authors and contributors
+ * Copyright (c) Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -22,21 +22,15 @@
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************/
 
-#ifndef TR_WINDOW_H
-#define TR_WINDOW_H
+#ifndef GTR_WINDOW_H
+#define GTR_WINDOW_H
 
 #include <gtk/gtk.h>
-#include <libtransmission/utils.h> /* tr_formatter_speed_KBps() */
 #include "tr-core.h"
 
-typedef GtkWindow TrWindow;
+GtkWidget        * gtr_window_new( GtkApplication * app, GtkUIManager * uim, TrCore * core );
+GtkTreeSelection * gtr_window_get_selection( GtkWindow * );
+void               gtr_window_set_busy( GtkWindow *, gboolean isBusy );
+void               gtr_window_refresh( GtkWindow * );
 
-GtkTreeSelection * tr_window_get_selection( TrWindow * );
-
-GtkWidget        * tr_window_new( GtkUIManager * uim, TrCore * core );
-
-void               tr_window_update( TrWindow * );
-
-void               tr_window_set_busy( TrWindow *, gboolean isBusy );
-
-#endif
+#endif /* GTR_WINDOW_H */
