@@ -1,13 +1,13 @@
 /*
- * This file Copyright (C) 2008-2010 Mnemosyne LLC
+ * This file Copyright (C) Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2.  Works owned by the
+ * This file is licensed by the GPL version 2. Works owned by the
  * Transmission project are granted a special exemption to clause 2(b)
  * so that the bulk of its code can remain under the MIT license.
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: json.h 9868 2010-01-04 21:00:47Z charles $
+ * $Id: json.h 11709 2011-01-19 13:48:47Z jordan $
  */
 
 #ifndef TR_JSON_H
@@ -17,7 +17,7 @@ extern "C" {
 #endif
 
 /** @ingroup tr_benc */
-int tr_jsonParse( const char * source, /* such as a filename.  only when logging an error */
+int tr_jsonParse( const char * source, /* Such as a filename. Only when logging an error */
                   const void *     vbuf,
                   size_t           len,
                   struct tr_benc * setme_benc,
