@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: InfoWindowController.m 11427 2010-11-20 16:09:48Z livings124 $
+ * $Id: InfoWindowController.m 13252 2012-03-13 02:55:15Z livings124 $
  *
- * Copyright (c) 2006-2010 Transmission authors and contributors
+ * Copyright (c) 2006-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -31,7 +31,6 @@
 #import "InfoFileViewController.h"
 #import "InfoOptionsViewController.h"
 #import "InfoTabButtonCell.h"
-#import "NSApplicationAdditions.h"
 #import "NSStringAdditions.h"
 #import "Torrent.h"
 
@@ -73,9 +72,13 @@ typedef enum
 
 - (void) awakeFromNib
 {
+    [fNoneSelectedField setStringValue: NSLocalizedString(@"No Torrents Selected", "Inspector -> selected torrents")];
+    
     //window location and size
     NSPanel * window = (NSPanel *)[self window];
     
+    [window setFloatingPanel: NO];
+    
     const CGFloat windowHeight = NSHeight([window frame]);
     
     [window setFrameAutosaveName: @"InspectorWindow"];
@@ -137,12 +140,12 @@ typedef enum
     if ([fViewController respondsToSelector: @selector(saveViewSize)])
         [fViewController saveViewSize];
     
-    [fGeneralViewController dealloc];
-    [fActivityViewController dealloc];
-    [fTrackersViewController dealloc];
-    [fPeersViewController dealloc];
-    [fFileViewController dealloc];
-    [fOptionsViewController dealloc];
+    [fGeneralViewController release];
+    [fActivityViewController release];
+    [fTrackersViewController release];
+    [fPeersViewController release];
+    [fFileViewController release];
+    [fOptionsViewController release];
     
     [fTorrents release];
     
@@ -177,9 +180,8 @@ typedef enum
 
 - (void) windowWillClose: (NSNotification *) notification
 {
-    if ([NSApp isOnSnowLeopardOrBetter] && fCurrentTabTag == TAB_FILE_TAG
-        && ([QLPreviewPanelSL sharedPreviewPanelExists] && [[QLPreviewPanelSL sharedPreviewPanel] isVisible]))
-        [[QLPreviewPanelSL sharedPreviewPanel] reloadData];
+    if (fCurrentTabTag == TAB_FILE_TAG && ([QLPreviewPanel sharedPreviewPanelExists] && [[QLPreviewPanel sharedPreviewPanel] isVisible]))
+        [[QLPreviewPanel sharedPreviewPanel] reloadData];
 }
 
 - (void) setTab: (id) sender
@@ -294,12 +296,25 @@ typedef enum
     
     NSRect windowRect = [window frame], viewRect = [view frame];
     
-    CGFloat difference = (NSHeight(viewRect) - oldHeight) * [window userSpaceScaleFactor];
+    const CGFloat difference = (NSHeight(viewRect) - oldHeight) * [window userSpaceScaleFactor];
     windowRect.origin.y -= difference;
     windowRect.size.height += difference;
     
     if ([fViewController respondsToSelector: @selector(saveViewSize)]) //a little bit hacky, but avoids requiring an extra method
     {
+        if ([window screen])
+        {
+            const CGFloat screenHeight = NSHeight([[window screen] visibleFrame]);
+            if (NSHeight(windowRect) > screenHeight)
+            {
+                const CGFloat difference = (screenHeight - NSHeight(windowRect)) * [window userSpaceScaleFactor];
+                windowRect.origin.y -= difference;
+                windowRect.size.height += difference;
+                
+                viewRect.size.height += difference;
+            }
+        }
+        
         [window setMinSize: NSMakeSize([window minSize].width, NSHeight(windowRect) - NSHeight(viewRect) + TAB_MIN_HEIGHT)];
         [window setMaxSize: NSMakeSize(FLT_MAX, FLT_MAX)];
     }
@@ -315,9 +330,9 @@ typedef enum
     [window setFrame: windowRect display: YES animate: oldTabTag != INVALID];
     [[window contentView] addSubview: view];
     
-    if ([NSApp isOnSnowLeopardOrBetter] && (fCurrentTabTag == TAB_FILE_TAG || oldTabTag == TAB_FILE_TAG)
-        && ([QLPreviewPanelSL sharedPreviewPanelExists] && [[QLPreviewPanelSL sharedPreviewPanel] isVisible]))
-        [[QLPreviewPanelSL sharedPreviewPanel] reloadData];
+    if ((fCurrentTabTag == TAB_FILE_TAG || oldTabTag == TAB_FILE_TAG)
+        && ([QLPreviewPanel sharedPreviewPanelExists] && [[QLPreviewPanel sharedPreviewPanel] isVisible]))
+        [[QLPreviewPanel sharedPreviewPanel] reloadData];
 }
 
 - (void) setNextTab
@@ -340,7 +355,7 @@ typedef enum
     [self setTab: nil];
 }
 
-- (void) swipeWithEvent:(NSEvent *) event
+- (void) swipeWithEvent: (NSEvent *) event
 {
     if ([event deltaX] < 0.0)
         [self setNextTab];
@@ -365,14 +380,13 @@ typedef enum
 
 - (BOOL) canQuickLook
 {
-    if (fCurrentTabTag != TAB_FILE_TAG || ![[self window] isVisible] || ![NSApp isOnSnowLeopardOrBetter])
+    if (fCurrentTabTag != TAB_FILE_TAG || ![[self window] isVisible])
         return NO;
     
     return [fFileViewController canQuickLook];
 }
 
-#warning uncomment (in header too)
-- (NSRect) quickLookSourceFrameForPreviewItem: (id /*<QLPreviewItem>*/) item
+- (NSRect) quickLookSourceFrameForPreviewItem: (id <QLPreviewItem>) item
 {
     return [fFileViewController quickLookSourceFrameForPreviewItem: item];
 }
@@ -393,6 +407,7 @@ typedef enum
             [fNameField setStringValue: [NSString stringWithFormat: NSLocalizedString(@"%@ Torrents Selected",
                                             "Inspector -> selected torrents"),
                                             [NSString formattedUInteger: numberSelected]]];
+            [fNameField setHidden: NO];
         
             uint64_t size = 0;
             NSUInteger fileCount = 0, magnetCount = 0;
@@ -441,14 +456,17 @@ typedef enum
                 [fBasicInfoField setStringValue: fileString];
                 [fBasicInfoField setToolTip: nil];
             }
+            [fBasicInfoField setHidden: NO];
+            
+            [fNoneSelectedField setHidden: YES];
         }
         else
         {
-            [fImageView setImage: [NSImage imageNamed: @"NSApplicationIcon"]];
+            [fImageView setImage: [NSImage imageNamed: NSImageNameApplicationIcon]];
+            [fNoneSelectedField setHidden: NO];
             
-            [fNameField setStringValue: NSLocalizedString(@"No Torrents Selected", "Inspector -> selected torrents")];
-            [fBasicInfoField setStringValue: @""];
-            [fBasicInfoField setToolTip: @""];
+            [fNameField setHidden: YES];
+            [fBasicInfoField setHidden: YES];
         }
         
         [fNameField setToolTip: nil];
@@ -457,19 +475,12 @@ typedef enum
     {
         Torrent * torrent = [fTorrents objectAtIndex: 0];
         
-        if ([NSApp isOnSnowLeopardOrBetter])
-            [fImageView setImage: [torrent icon]];
-        else
-        {
-            NSImage * icon = [[torrent icon] copy];
-            [icon setFlipped: NO];
-            [fImageView setImage: icon];
-            [icon release];
-        }
+        [fImageView setImage: [torrent icon]];
         
         NSString * name = [torrent name];
         [fNameField setStringValue: name];
         [fNameField setToolTip: name];
+        [fNameField setHidden: NO];
         
         if (![torrent isMagnet])
         {
@@ -494,6 +505,9 @@ typedef enum
             [fBasicInfoField setStringValue: NSLocalizedString(@"Magnetized transfer", "Inspector -> selected torrents")];
             [fBasicInfoField setToolTip: nil];
         }
+        [fBasicInfoField setHidden: NO];
+        
+        [fNoneSelectedField setHidden: YES];
     }
     
     [fGeneralViewController setInfoForTorrents: fTorrents];
