@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: Torrent.h 13162 2012-01-14 17:12:04Z livings124 $
+ * $Id: Torrent.h 13379 2012-07-07 02:14:08Z livings124 $
  *
  * Copyright (c) 2006-2012 Transmission authors and contributors
  *
@@ -46,6 +46,8 @@
     NSIndexSet * fPreviousFinishedIndexes;
     NSDate * fPreviousFinishedIndexesDate;
     
+    BOOL fRemoveWhenFinishSeeding;
+    
     NSInteger fGroupValue;
     
     BOOL fResumeOnWake;
@@ -114,6 +116,8 @@
 - (void) setMaxPeerConnect: (uint16_t) count;
 - (uint16_t) maxPeerConnect;
 
+@property (nonatomic) BOOL removeWhenFinishSeeding;
+
 - (BOOL) waitingToStart;
 
 - (tr_priority_t) priority;
