@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: Torrent.m 13251 2012-03-13 02:52:11Z livings124 $
+ * $Id: Torrent.m 13379 2012-07-07 02:14:08Z livings124 $
  *
  * Copyright (c) 2006-2012 Transmission authors and contributors
  *
@@ -38,6 +38,7 @@
 - (id) initWithPath: (NSString *) path hash: (NSString *) hashString torrentStruct: (tr_torrent *) torrentStruct
         magnetAddress: (NSString *) magnetAddress lib: (tr_session *) lib
         groupValue: (NSNumber *) groupValue
+        removeWhenFinishSeeding: (NSNumber *) removeWhenFinishSeeding
         timeMachineExcludeLocation: (NSString *) timeMachineExclude
         downloadFolder: (NSString *) downloadFolder
         legacyIncompleteFolder: (NSString *) incompleteFolder;
@@ -102,11 +103,15 @@ int trashDataFile(const char * filename)
 
 @implementation Torrent
 
+#warning remove ivars in header when 64-bit only (or it compiles in 32-bit mode)
+@synthesize removeWhenFinishSeeding = fRemoveWhenFinishSeeding;
+
 - (id) initWithPath: (NSString *) path location: (NSString *) location deleteTorrentFile: (BOOL) torrentDelete
         lib: (tr_session *) lib
 {
     self = [self initWithPath: path hash: nil torrentStruct: NULL magnetAddress: nil lib: lib
             groupValue: nil
+            removeWhenFinishSeeding: nil
             timeMachineExcludeLocation: nil
             downloadFolder: location
             legacyIncompleteFolder: nil];
@@ -123,6 +128,7 @@ int trashDataFile(const char * filename)
 {
     self = [self initWithPath: nil hash: nil torrentStruct: torrentStruct magnetAddress: nil lib: lib
             groupValue: nil
+            removeWhenFinishSeeding: nil
             timeMachineExcludeLocation: nil
             downloadFolder: location
             legacyIncompleteFolder: nil];
@@ -134,6 +140,7 @@ int trashDataFile(const char * filename)
 {
     self = [self initWithPath: nil hash: nil torrentStruct: nil magnetAddress: address
             lib: lib groupValue: nil
+            removeWhenFinishSeeding: nil
             timeMachineExcludeLocation: nil
             downloadFolder: location legacyIncompleteFolder: nil];
     
@@ -148,6 +155,7 @@ int trashDataFile(const char * filename)
                 magnetAddress: nil
                 lib: lib
                 groupValue: [history objectForKey: @"GroupValue"]
+                removeWhenFinishSeeding: [history objectForKey: @"RemoveWhenFinishSeeding"]
                 timeMachineExcludeLocation: [history objectForKey: @"TimeMachineExcludeLocation"]
                 downloadFolder: [history objectForKey: @"DownloadFolder"] //upgrading from versions < 1.80
                 legacyIncompleteFolder: [[history objectForKey: @"UseIncompleteFolder"] boolValue] //upgrading from versions < 1.80
@@ -197,7 +205,8 @@ int trashDataFile(const char * filename)
                                         [self hashString], @"TorrentHash",
                                         [NSNumber numberWithBool: [self isActive]], @"Active",
                                         [NSNumber numberWithBool: [self waitingToStart]], @"WaitToStart",
-                                        [NSNumber numberWithInt: fGroupValue], @"GroupValue", nil];
+                                        [NSNumber numberWithInt: fGroupValue], @"GroupValue",
+                                        [NSNumber numberWithBool: fRemoveWhenFinishSeeding], @"RemoveWhenFinishSeeding", nil];
     
     if (fTimeMachineExclude)
         [history setObject: fTimeMachineExclude forKey: @"TimeMachineExcludeLocation"];
@@ -492,18 +501,18 @@ int trashDataFile(const char * filename)
     return tr_torrentSetPriority(fHandle, priority);
 }
 
-#warning when 10.6-only use recycleURLs:completionHandler:
 + (void) trashFile: (NSString *) path
 {
     //attempt to move to trash
     if (![[NSWorkspace sharedWorkspace] performFileOperation: NSWorkspaceRecycleOperation
-        source: [path stringByDeletingLastPathComponent] destination: @""
-        files: [NSArray arrayWithObject: [path lastPathComponent]] tag: nil])
+                                                      source: [path stringByDeletingLastPathComponent] destination: @""
+                                                       files: [NSArray arrayWithObject: [path lastPathComponent]] tag: nil])
     {
         //if cannot trash, just delete it (will work if it's on a remote volume)
         NSError * error;
         if (![[NSFileManager defaultManager] removeItemAtPath: path error: &error])
-            NSLog(@"Could not trash %@: %@", path, [error localizedDescription]);
+            NSLog(@"old Could not trash %@: %@", path, [error localizedDescription]);
+        else {NSLog(@"old removed %@", path);}
     }
 }
 
@@ -607,7 +616,7 @@ int trashDataFile(const char * filename)
 - (NSImage *) icon
 {
     if ([self isMagnet])
-        return [NSImage imageNamed: @"Magnet.png"];
+        return [NSImage imageNamed: @"Magnet"];
     
     #warning replace kGenericFolderIcon stuff with NSImageNameFolder on 10.6
     if (!fIcon)
@@ -1611,6 +1620,7 @@ int trashDataFile(const char * filename)
 - (id) initWithPath: (NSString *) path hash: (NSString *) hashString torrentStruct: (tr_torrent *) torrentStruct
         magnetAddress: (NSString *) magnetAddress lib: (tr_session *) lib
         groupValue: (NSNumber *) groupValue
+        removeWhenFinishSeeding: (NSNumber *) removeWhenFinishSeeding
         timeMachineExcludeLocation: (NSString *) timeMachineExclude
         downloadFolder: (NSString *) downloadFolder
         legacyIncompleteFolder: (NSString *) incompleteFolder
@@ -1674,6 +1684,8 @@ int trashDataFile(const char * filename)
 	
     fGroupValue = groupValue ? [groupValue intValue] : [[GroupsController groups] groupIndexForTorrent: self]; 
     
+    fRemoveWhenFinishSeeding = removeWhenFinishSeeding ? [removeWhenFinishSeeding boolValue] : [fDefaults boolForKey: @"RemoveWhenFinishSeeding"];
+    
     [[NSNotificationCenter defaultCenter] addObserver: self selector: @selector(checkGroupValueForRemoval:)
         name: @"GroupValueRemoved" object: nil];
     
