@@ -7,7 +7,7 @@
  *
  * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
  *
- * $Id: session.h 11209 2010-09-14 06:23:48Z Longinus00 $
+ * $Id: session.h 12607 2011-08-01 22:24:24Z jordan $
  */
 
 #ifndef TR_APP_SESSION_H
@@ -29,6 +29,7 @@ class AddData;
 
 extern "C"
 {
+    struct evbuffer;
     struct tr_benc;
 }
 
@@ -74,7 +75,7 @@ class Session: public QObject
         void updateStats( struct tr_benc * args );
         void updateInfo( struct tr_benc * args );
         void parseResponse( const char * json, size_t len );
-        static void localSessionCallback( tr_session *, const char *, size_t, void * );
+        static void localSessionCallback( tr_session *, struct evbuffer *, void * );
 
     public:
         void exec( const char * json );
@@ -104,6 +105,11 @@ class Session: public QObject
     public slots:
         void pauseTorrents( const QSet<int>& torrentIds = QSet<int>() );
         void startTorrents( const QSet<int>& torrentIds = QSet<int>() );
+        void startTorrentsNow( const QSet<int>& torrentIds = QSet<int>() );
+        void queueMoveTop( const QSet<int>& torrentIds = QSet<int>() );
+        void queueMoveUp( const QSet<int>& torrentIds = QSet<int>() );
+        void queueMoveDown( const QSet<int>& torrentIds = QSet<int>() );
+        void queueMoveBottom( const QSet<int>& torrentIds = QSet<int>() );
         void refreshSessionInfo( );
         void refreshSessionStats( );
         void refreshActiveTorrents( );
