@@ -76,10 +76,10 @@ Dialog.prototype = {
 	{
 		if (!isMobileDevice)
 			$('.dialog_container').hide();
-		setInnerHTML(this._heading[0], dialog_heading);
-		setInnerHTML(this._message[0], dialog_message);
-		setInnerHTML(this._cancel_button[0], cancel_button_label || 'Cancel');
-		setInnerHTML(this._confirm_button[0], confirm_button_label);
+		setTextContent(this._heading[0], dialog_heading);
+		setTextContent(this._message[0], dialog_message);
+		setTextContent(this._cancel_button[0], cancel_button_label || 'Cancel');
+		setTextContent(this._confirm_button[0], confirm_button_label);
 		this._confirm_button.show();
 		this._callback_function = callback_function;
 		this._callback_data = callback_data;
@@ -96,11 +96,11 @@ Dialog.prototype = {
 	alert: function(dialog_heading, dialog_message, cancel_button_label) {
 		if (!isMobileDevice)
 			$('.dialog_container').hide();
-		setInnerHTML(this._heading[0], dialog_heading);
-		setInnerHTML(this._message[0], dialog_message);
+		setTextContent(this._heading[0], dialog_heading);
+		setTextContent(this._message[0], dialog_message);
 		// jquery::hide() doesn't work here in Safari for some odd reason
 		this._confirm_button.css('display', 'none');
-		setInnerHTML(this._cancel_button[0], cancel_button_label);
+		setTextContent(this._cancel_button[0], cancel_button_label);
 		// Just in case
 		$('#upload_container').hide();
 		$('body').addClass('dialog_showing');
